@@ -98,19 +98,19 @@ class CratePGDialect(PGDialect_psycopg2):
 
     @classmethod
     def dbapi(cls):
-        import psycopg2
+        import psycopg2Crate
 
-        return psycopg2
+        return psycopg2Crate
 
     @classmethod
     def _psycopg2_extensions(cls):
-        from psycopg2 import extensions
+        from psycopg2Crate import extensions
 
         return extensions
 
     @classmethod
     def _psycopg2_extras(cls):
-        from psycopg2 import extras
+        from psycopg2Crate import extras
 
         return extras
 
